@@ -1,4 +1,4 @@
-#include "cs_directsum.h"
+#include "MCMCglmm.h"
 
 void cs_directsumupdate(cs **KGinv, int nG, int nGR, const cs *C){
 
